@@ -14,42 +14,46 @@
  *
  * @category   Services
  * @package    Services_Hatena
- * @author     gooooooogle
- * @copyright  2006 gooooooogle
+ * @author     Makoto Tanaka
+ * @copyright  2006 Makoto Tanaka
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
  * @version    CVS: $Id$
  */
 
 /**
- * 拾쥯饹
+ * Services_Hatena_asin
  *
- * Υ饹ϤϤƤʤ拾쥯APIѤ뤿Υ饹Ǥ
+ * Interface for Hatena::Bookmark's getAsinCount XML-RPC API
+ * This class make a call to 'bookmark.getAsinCount' method of the Hatena Web
+ * Services. The arguments is ASIN Code to get a number of registrations
+ * in Hatena.
+ * (ASIN Code : Amazon Standard Identification Number)
  *
  * @category   Services
  * @package    Services_Hatena
- * @author     gooooooogle
- * @copyright  2006 gooooooogle
+ * @author     Makoto Tanaka
+ * @copyright  2006 Makoto Tanaka
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
  * @version    CVS: $Id$
  */
-class Services_Hatena_asin extends Services_Hatena_base {
+class Services_Hatena_asin extends Services_Hatena_base
+{
     /**
-     * 󥹥ȥ饯
+     * constructer
      *
      * @access  public
      */
     public function Services_Hatena_asin() {}
 
     /**
-     * ¹Դؿ
-     *
-     * ǤդASIN ɤˤĤ拾쥯֤ޤ
+     * execute function
      *
      * @access  public
-     * @param   string $asin ASIN 
-     * @return  string 拾쥯
+     * @param   string $asin ASIN Code
+     * @return  string number of collectioned asin
      */
-    public function execute($asin) {
+    public function execute($asin)
+    {
         mb_internal_encoding('euc');
         require_once "XML/RPC.php";
 
@@ -60,12 +64,13 @@ class Services_Hatena_asin extends Services_Hatena_base {
         $response = $client->send($msg);
 
         if (!$response->faultCode()) {
-          $r = $response->value()->scalarval();
-          $this->result = $r[$asin]->me["int"];
-          return $this->getResult();
-        }
-        else {
-          // ⤷ޤ
+            $r = $response->value()->scalarval();
+            $this->result = $r[$asin]->me["int"];
+            return $this->getResult();
+        } else {
+            return PEAR::raiseError("missing the result.");
         }
     }
 }
+?>
+
