@@ -2,7 +2,7 @@
 /* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
 
 /**
- * ֥åޡ
+ * bookmarknum
  *
  * PHP version 5
  *
@@ -14,42 +14,47 @@
  *
  * @category   Services
  * @package    Services_Hatena
- * @author     gooooooogle
- * @copyright  2006 gooooooogle
+ * @author     Makoto Tanaka
+ * @copyright  2006 Makoto Tanaka
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
  * @version    CVS: $Id$
  */
 
 /**
- * ֥åޡ饹
+ * bookmarknum
  *
- * Υ饹ϥ֥åޡAPIѤ뤿Υ饹Ǥ.
+ * Interface for Hatena::Bookmark's getCount XML-RPC API
+ * This class make a call to 'bookmark.getCount' method of the Hatena Web
+ * Services. The arguments is URL to get a number of registrations
+ * in Hatena::Bookmark.
  *
  * @category   Services
  * @package    Services_Hatena
- * @author     gooooooogle
- * @copyright  2006 gooooooogle
+ * @author     Makoto Tanaka
+ * @copyright  2006 Makoto Tanaka
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
  * @version    CVS: $Id$
  */
-class Services_Hatena_bookmarknum extends Services_Hatena_base {
+class Services_Hatena_bookmarknum extends Services_Hatena_base
+{
     /**
-     * 󥹥ȥ饯
+     * constructer
      *
      * @access  public
      */
     public function Services_Hatena_bookmarknum() {}
 
     /**
-     * ¹Դؿ
+     * execute
      *
-     * ǤդURLˤĤƥ֥åޡޤ.
+     * return number of bookmarked
      *
      * @access  public
      * @param   string $url URL
-     * @return  integer 
+     * @return  integer number of bookmarked
      */
-    public function execute($url) {
+    public function execute($url)
+    {
         mb_internal_encoding('euc');
         require_once "XML/RPC.php";
 
@@ -60,12 +65,13 @@ class Services_Hatena_bookmarknum extends Services_Hatena_base {
         $response = $client->send($msg);
 
         if (!$response->faultCode()) {
-          $r = $response->value()->scalarval();
-          $this->result = $r[$url]->me["int"];
-          return $this->getResult();
-        }
-        else {
-          // ⤷ޤ
+            $r = $response->value()->scalarval();
+            $this->result = $r[$url]->me["int"];
+            return $this->getResult();
+        } else {
+            return PEAR::raiseError("missing the result.");
         }
     }
 }
+?>
+
