@@ -14,42 +14,44 @@
  *
  * @category   Services
  * @package    Services_Hatena
- * @author     gooooooogle
- * @copyright  2006 gooooooogle
+ * @author     Makoto Tanaka
+ * @copyright  2006 Makoto Tanaka
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
  * @version    CVS: $Id$
  */
 
 /**
- * ϤƤexist
+ * Services_Hatena_exist
  *
- * Υ饹ϤϤƤexist APIѤ뤿Υ饹Ǥ.
+ * Interface for Hatena's exist REST API
+ * This class make a method to get Resources of a URL in Hatena Services.
+ * The arguments is URL to get information of registrations in Hatena.
  *
  * @category   Services
  * @package    Services_Hatena
- * @author     gooooooogle
- * @copyright  2006 gooooooogle
+ * @author     Makoto Tanaka
+ * @copyright  2006 Makoto Tanaka
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
  * @version    CVS: $Id$
  */
-class Services_Hatena_exist extends Services_Hatena_base {
+class Services_Hatena_exist extends Services_Hatena_base
+{
     /**
-     * 󥹥ȥ饯
+     * constructer
      *
      * @access  public
      */
     public function Services_Hatena_exist() {}
 
     /**
-     * ¹Դؿ
-     *
-     * URL˴ؤ꥽ϤƤʤγƼ掠ӥޤ.
+     * execute
      *
      * @access  public
      * @param   string $url URL
-     * @return  string ꥽
+     * @return  string information
      */
-    public function execute($url) {
+    public function execute($url)
+    {
         mb_internal_encoding('euc');
         require_once "HTTP/Request.php";
 
@@ -81,12 +83,16 @@ class Services_Hatena_exist extends Services_Hatena_base {
          *          [1] => 1
          *          [2] => 577
          *         )
+         *
+         * if the information is nothing, i will return null.
          */
-        if ( $matches[1][0] && $matches[2][0]) 
-          $this->result[$matches[1][0]] = $matches[2][0];
-        if ( $matches[1][1] && $matches[2][1]) 
-          $this->result[$matches[1][1]] = $matches[2][1];
-        if ( $matches[1][2] && $matches[2][2]) 
-          $this->result[$matches[1][2]] = $matches[2][2];
+        if ($matches[1][0] && $matches[2][0]) 
+            $this->result[$matches[1][0]] = $matches[2][0];
+        if ($matches[1][1] && $matches[2][1]) 
+            $this->result[$matches[1][1]] = $matches[2][1];
+        if ($matches[1][2] && $matches[2][2]) 
+            $this->result[$matches[1][2]] = $matches[2][2];
     }
 }
+?>
+
