@@ -2,7 +2,7 @@
 /* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
 
 /**
- * 
+ * search
  *
  * PHP version 5
  *
@@ -14,165 +14,151 @@
  *
  * @category   Services
  * @package    Services_Hatena
- * @author     gooooooogle
- * @copyright  2006 gooooooogle
+ * @author     Makoto Tanaka
+ * @copyright  2006 Makoto Tanaka
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
  * @version    CVS: $Id$
  */
 
 /**
- * 饹
+ * Services_Hatena_search
  *
- * Υ饹ϤϤƤʸAPIѥ饹Ǥ.
+ * Interface for Hatena::Search with OpernSerch.
+ * This class make Search function from Hatena.
+ * The arguments is keyword to get a search result from Hatena.
  *
  * @category   Services
  * @package    Services_Hatena
- * @author     gooooooogle
- * @copyright  2006 gooooooogle
+ * @author     Makoto Tanaka
+ * @copyright  2006 Makoto Tanaka
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
  * @version    CVS: $Id$
  */
-class Services_Hatena_search extends Services_Hatena_base {
+class Services_Hatena_search extends Services_Hatena_base
+{
     /**
-     * OpenSearch Description Document Ǽޤ.
+     * To store OpenSearch Description Document URI.
      *
      * @see Services_Hatena_search
      */
     protected $osxml_url = "http://search.hatena.ne.jp/osxml";
 
     /**
-     * OpenSearch֥ȤǼޤ.
+     * To store OpenSearch object
      *
      * @see Services_Hatena_search
      */
-    protected $os     = null;
+    protected $os = null;
 
     /**
-     * 󥹥ȥ饯
+     * constructer
      *
-     * OpenSearch֥Ȥޤ.
+     * create OpenSearch object
      *
      * @access  public
      */
-    public function Services_Hatena_search() {
+    public function Services_Hatena_search()
+    {
         require_once 'Services/OpenSearch.php';
-        $this->os    = new Services_OpenSearch($this->osxml_url);
+        $this->os = new Services_OpenSearch($this->osxml_url);
     }
 
     /**
-     * ¹Դؿ
-     *
-     * ϤƤʸԤؿǤ.
+     * execute
      *
      * @access public
-     * @param  string $keyword 
-     * @return array 
+     * @param  string $keyword keyword
+     * @return array search result
      */
-    public function execute($keyword) {
+    public function execute($keyword)
+    {
         $keyword = mb_convert_encoding($keyword, "UTF-8", "ASCII,JIS,UTF-8,EUC-JP,SJIS");
         $this->result = $this->os->search($keyword);
+
         return $this->getResult();
     }
 
     /**
-     * ̿ؿ
-     *
-     * ҥåȿ֤ޤ.
+     * To get number of search result
      *
      * @access  public
-     * @return  intger ҥåȿ
+     * @return  intger number of search result
      */
-    public function getTotalSearchResult() {
+    public function getTotalSearchResult()
+    {
         return $this->os->getTotalResults();
     }
 
     /**
-     * ϥڡåȴؿ
+     * To set start page for search
      *
-     * 򳫻Ϥڡֹ򥻥åȤޤ.
-     *
-     * @access  public
-     * @param integer $p ڡֹ
+     * @access public
+     * @param integer $p page number
      */
-    public function setStartPage($p) {
+    public function setStartPage($p)
+    {
         $this->os->setStartPage($p);
     }
 
     /**
-     * ϥڡؿ
+     * To get start page for search
      *
-     * 򳫻Ϥڡֹޤ.
-     *
-     * @access  public
-     * @return  intger ڡֹ
+     * @access public
+     * @return intger page number
      */
-    public function getStartPage() {
+    public function getStartPage()
+    {
         return $this->os->getStartPage();
     }
 
     /**
-     * ȥؿ
+     * Retrieves the currently set entry count of per page.
      *
-     * 1ڡΥȥޤ.
-     *
-     * @access  public
-     * @return  intger ȥ
+     * @access public
+     * @return intger entry count
      */
-    public function getCount() {
+    public function getCount()
+    {
         return $this->os->getCount();
     }
 
     /**
-     * ȥåȴؿ(̤)
+     * To get previous page number
      *
-     * 1ڡΥȥ򥻥åȤޤ.
-     *
-     * @access  public
-     * @param integer $c ȥ
+     * @access public
+     * @return page number
      */
-    public function setCount($c) {
-        //! @todo i have a bug.
-        // return $this->os->setCount($c);
+    public function getPrevPage()
+    {
+        $s = $this->getStartPage();
+        $r = $this->getTotalSearchResult();
+        $c = $this->getCount();
+  
+        if ($s >= 2) {
+            return $s - 1;
+        }
+        else {
+        }
     }
 
     /**
-     * ڡؿ
+     * To get next page number
      *
-     * ڡֹ֤ޤ.
-     *
-     * @access  public
-     * @return ڡֹ
+     * @access public
+     * @return page number
      */
-    public function getPrevPage() {
+    public function getNextPage()
+    {
         $s = $this->getStartPage();
         $r = $this->getTotalSearchResult();
         $c = $this->getCount();
   
-        if ( $s >= 2 ) {
-           return $s - 1;
+        if (($r / $c) >= $s) {
+            return $s + 1;
         }
         else {
-          // ⤷ޤ
-        }
-    }
-    /**
-     * ڡؿ
-     *
-     * ڡֹ֤ޤ.
-     *
-     * @access  public
-     * @return ڡֹ
-     */
-    public function getNextPage() {
-        $s = $this->getStartPage();
-        $r = $this->getTotalSearchResult();
-        $c = $this->getCount();
-  
-        if ( ($r / $c) >= $s ) {
-           return $s + 1;
-        }
-        else {
-          // ⤷ޤ
         }
     }
 }
+?>
+
