@@ -2,7 +2,7 @@
 /* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
 
 /**
- * ϤƤ ǥѥå
+ * Services_Hatena Dispatcher
  *
  * PHP version 5
  *
@@ -14,8 +14,8 @@
  *
  * @category   Services
  * @package    Services_Hatena
- * @author     gooooooogle
- * @copyright  2006 gooooooogle
+ * @author     Makoto Tanaka
+ * @copyright  2006 Makoto Tanaka
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
  * @version    CVS: $Id$
  */
@@ -27,63 +27,63 @@ require_once(HATENA_BASEDIR . "base.php");
 
 
 /**
- * ϤƤ 𴴥饹
+ * Serveces Hatena Basic Class
  *
- * Υ饹ϤϤƤʤΥ֥ӥAPI(,ư,֥åޡ,
- * եȥ饤,֥åޡ,拾쥯,Ϣ۸,ϤƤexist)
- * Ѥ뤿γƥ饹֥Ȥ뤿δ𴴥饹Ǥ.
+ * This class is for creating object using Hatena's 
+ * Web Services API (search, autolink, bookmark, bookmarknum, foto, asin, similar,exist).
  *
  * @category   Services
  * @package    Services_Hatena
- * @author     gooooooogle
- * @copyright  2006 gooooooogle
+ * @author     Makoto Tanaka
+ * @copyright  2006 Makoto Tanaka
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
  * @version    CVS: $Id$
  */
-class Services_Hatena {
+class Services_Hatena
+{
     /**
-     * 󥹥ȥ饯.
+     * constructer.
      *
      * @access  public
      */
     public function __construct() {}
 
     /**
-     * 󥹥ȥ饯.
+     * create class and return.
      *
      * @access  public
-     */
-    // public function Services_hatena() {}
-
-    /**
-     * ƥ饹֥Ȥ֤ޤ.
-     *
-     * 륯饹μꤷ饹֥Ȥޤ.
-     *
-     * @access  public
-     * @param   string $type 륵ӥʸꤷޤ. ʲΤΤɤ줫ǽǤ(search, autolink, asin, bookmarknum, bookmark, similar, photo, exist)
-     * @return object ˴Ť饹֥
+     * @param   string $type servics name (search, autolink, asin, bookmarknum, bookmark, similar, foto, exist)
+     * @return object class object for using API.
      */
     public function create($type)
     {
 
         switch ($type) {
 
-        case "search"      : // APIѤ뤿Υ饹Ǥ
-        case "autolink"    : // ưAPIѤ뤿Υ饹Ǥ
-        case "bookmarknum" : // ֥åޡAPIѤ뤿Υ饹Ǥ
-        case "asin"        : // 拾쥯APIѤ뤿Υ饹Ǥ
-        case "similar"     : // Ϣ۸APIѤ뤿Υ饹Ǥ
-        case "bookmark"    : // ֥åޡAPIѤ뤿Υ饹Ǥ
-        case "photo"       : // եȥ饤APIѤ뤿Υ饹Ǥ
-        case "exist"       : // exist APIѤ뤿Υ饹Ǥ
+        case "search"      : // class for Search API
+        case "autolink"    : // class for autolink API
+        case "bookmarknum" : // class for bookmarknum API
+        case "asin"        : // class for asin API
+        case "similar"     : // class for similar API
+        case "bookmark"    : // class for bookmark API
+        case "foto"        : // class for foto API
+        case "exist"       : // class for exist API
+
             require_once(HATENA_BASEDIR . $type . ".php");
             $classname = "Services_Hatena_" . $type;
-            return new $classname;
+
+            if (class_exists($classname)) {
+                return new $classname;
+            } else {
+                return PEAR::raiseError("missing the class.");
+            }
+            break;
 
         default :
-            // ⤷ޤ
+            return PEAR::raiseError("missing the class.");
             break;
         }
     }
 }
+?>
+
